Class StandardThreeImageTextModule
- java.lang.Object
-
- software.amazon.spapi.models.apluscontent.v2020_11_01.StandardThreeImageTextModule
-
public class StandardThreeImageTextModule extends java.lang.ObjectThree standard images with text, presented across a single row.
-
-
Constructor Summary
Constructors Constructor Description StandardThreeImageTextModule()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StandardThreeImageTextModuleblock1(StandardImageTextBlock block1)StandardThreeImageTextModuleblock2(StandardImageTextBlock block2)StandardThreeImageTextModuleblock3(StandardImageTextBlock block3)booleanequals(java.lang.Object o)StandardImageTextBlockgetBlock1()Get block1StandardImageTextBlockgetBlock2()Get block2StandardImageTextBlockgetBlock3()Get block3TextComponentgetHeadline()Get headlineinthashCode()StandardThreeImageTextModuleheadline(TextComponent headline)voidsetBlock1(StandardImageTextBlock block1)voidsetBlock2(StandardImageTextBlock block2)voidsetBlock3(StandardImageTextBlock block3)voidsetHeadline(TextComponent headline)java.lang.StringtoString()
-
-
-
Method Detail
-
headline
public StandardThreeImageTextModule headline(TextComponent headline)
-
getHeadline
public TextComponent getHeadline()
Get headline- Returns:
- headline
-
setHeadline
public void setHeadline(TextComponent headline)
-
block1
public StandardThreeImageTextModule block1(StandardImageTextBlock block1)
-
getBlock1
public StandardImageTextBlock getBlock1()
Get block1- Returns:
- block1
-
setBlock1
public void setBlock1(StandardImageTextBlock block1)
-
block2
public StandardThreeImageTextModule block2(StandardImageTextBlock block2)
-
getBlock2
public StandardImageTextBlock getBlock2()
Get block2- Returns:
- block2
-
setBlock2
public void setBlock2(StandardImageTextBlock block2)
-
block3
public StandardThreeImageTextModule block3(StandardImageTextBlock block3)
-
getBlock3
public StandardImageTextBlock getBlock3()
Get block3- Returns:
- block3
-
setBlock3
public void setBlock3(StandardImageTextBlock block3)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-