Class CreateUnexpectedProblemRequest
- java.lang.Object
-
- software.amazon.spapi.models.messaging.v1.CreateUnexpectedProblemRequest
-
public class CreateUnexpectedProblemRequest extends java.lang.ObjectThe request schema for the createUnexpectedProblem operation.
-
-
Constructor Summary
Constructors Constructor Description CreateUnexpectedProblemRequest()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(java.lang.Object o)java.lang.StringgetText()The text to be sent to the buyer.inthashCode()voidsetText(java.lang.String text)CreateUnexpectedProblemRequesttext(java.lang.String text)java.lang.StringtoString()
-
-
-
Method Detail
-
text
public CreateUnexpectedProblemRequest text(java.lang.String text)
-
getText
public java.lang.String getText()
The text to be sent to the buyer. Only links related to unexpected problem calls are allowed. Do not include HTML or email addresses. The text must be written in the buyer's language of preference, which can be retrieved from the GetAttributes operation.- Returns:
- text
-
setText
public void setText(java.lang.String text)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-