Class GetMessagingActionsForOrderResponseEmbedded
- java.lang.Object
-
- software.amazon.spapi.models.messaging.v1.GetMessagingActionsForOrderResponseEmbedded
-
public class GetMessagingActionsForOrderResponseEmbedded extends java.lang.ObjectThe messaging actions response that is associated with the specified `amazonOrderId`.
-
-
Constructor Summary
Constructors Constructor Description GetMessagingActionsForOrderResponseEmbedded()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description GetMessagingActionsForOrderResponseEmbeddedactions(java.util.List<GetMessagingActionResponse> actions)GetMessagingActionsForOrderResponseEmbeddedaddActionsItem(GetMessagingActionResponse actionsItem)booleanequals(java.lang.Object o)java.util.List<GetMessagingActionResponse>getActions()Get actionsinthashCode()voidsetActions(java.util.List<GetMessagingActionResponse> actions)java.lang.StringtoString()
-
-
-
Method Detail
-
actions
public GetMessagingActionsForOrderResponseEmbedded actions(java.util.List<GetMessagingActionResponse> actions)
-
addActionsItem
public GetMessagingActionsForOrderResponseEmbedded addActionsItem(GetMessagingActionResponse actionsItem)
-
getActions
public java.util.List<GetMessagingActionResponse> getActions()
Get actions- Returns:
- actions
-
setActions
public void setActions(java.util.List<GetMessagingActionResponse> actions)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-