Class EventBridgeResourceSpecification
- java.lang.Object
-
- software.amazon.spapi.models.notifications.v1.EventBridgeResourceSpecification
-
public class EventBridgeResourceSpecification extends java.lang.ObjectThe information required to create an Amazon EventBridge destination.
-
-
Constructor Summary
Constructors Constructor Description EventBridgeResourceSpecification()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description EventBridgeResourceSpecificationaccountId(java.lang.String accountId)booleanequals(java.lang.Object o)java.lang.StringgetAccountId()The identifier for the AWS account that is responsible for charges related to receiving notifications.java.lang.StringgetRegion()The AWS region in which you will be receiving the notifications.inthashCode()EventBridgeResourceSpecificationregion(java.lang.String region)voidsetAccountId(java.lang.String accountId)voidsetRegion(java.lang.String region)java.lang.StringtoString()
-
-
-
Method Detail
-
region
public EventBridgeResourceSpecification region(java.lang.String region)
-
getRegion
public java.lang.String getRegion()
The AWS region in which you will be receiving the notifications.- Returns:
- region
-
setRegion
public void setRegion(java.lang.String region)
-
accountId
public EventBridgeResourceSpecification accountId(java.lang.String accountId)
-
getAccountId
public java.lang.String getAccountId()
The identifier for the AWS account that is responsible for charges related to receiving notifications.- Returns:
- accountId
-
setAccountId
public void setAccountId(java.lang.String accountId)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-