Class ProcessingDirective
- java.lang.Object
-
- software.amazon.spapi.models.notifications.v1.ProcessingDirective
-
public class ProcessingDirective extends java.lang.ObjectAdditional information passed to the subscription to control the processing of notifications. For example, you can use an `eventFilter` to customize your subscription to send notifications for only the specified `marketplaceId`s, or select the aggregation time period at which to send notifications (for example: limit to one notification every five minutes for high frequency notifications). The specific features available vary depending on the `notificationType`. This feature is currently only supported by the `ANY_OFFER_CHANGED` and `ORDER_CHANGE` `notificationType`s.
-
-
Constructor Summary
Constructors Constructor Description ProcessingDirective()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(java.lang.Object o)ProcessingDirectiveeventFilter(EventFilter eventFilter)EventFiltergetEventFilter()Get eventFilterinthashCode()voidsetEventFilter(EventFilter eventFilter)java.lang.StringtoString()
-
-
-
Method Detail
-
eventFilter
public ProcessingDirective eventFilter(EventFilter eventFilter)
-
getEventFilter
public EventFilter getEventFilter()
Get eventFilter- Returns:
- eventFilter
-
setEventFilter
public void setEventFilter(EventFilter eventFilter)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-