Class AppointmentTimeInput
- java.lang.Object
-
- software.amazon.spapi.models.services.v1.AppointmentTimeInput
-
public class AppointmentTimeInput extends java.lang.ObjectThe input appointment time details.
-
-
Constructor Summary
Constructors Constructor Description AppointmentTimeInput()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description AppointmentTimeInputdurationInMinutes(java.lang.Integer durationInMinutes)booleanequals(java.lang.Object o)java.lang.IntegergetDurationInMinutes()The duration of an appointment in minutes.org.threeten.bp.OffsetDateTimegetStartTime()The date, time in UTC for the start time of an appointment in ISO 8601 format.inthashCode()voidsetDurationInMinutes(java.lang.Integer durationInMinutes)voidsetStartTime(org.threeten.bp.OffsetDateTime startTime)AppointmentTimeInputstartTime(org.threeten.bp.OffsetDateTime startTime)java.lang.StringtoString()
-
-
-
Method Detail
-
startTime
public AppointmentTimeInput startTime(org.threeten.bp.OffsetDateTime startTime)
-
getStartTime
public org.threeten.bp.OffsetDateTime getStartTime()
The date, time in UTC for the start time of an appointment in ISO 8601 format.- Returns:
- startTime
-
setStartTime
public void setStartTime(org.threeten.bp.OffsetDateTime startTime)
-
durationInMinutes
public AppointmentTimeInput durationInMinutes(java.lang.Integer durationInMinutes)
-
getDurationInMinutes
public java.lang.Integer getDurationInMinutes()
The duration of an appointment in minutes.- Returns:
- durationInMinutes
-
setDurationInMinutes
public void setDurationInMinutes(java.lang.Integer durationInMinutes)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-