Class CreateReservationRecord
- java.lang.Object
-
- software.amazon.spapi.models.services.v1.CreateReservationRecord
-
public class CreateReservationRecord extends java.lang.Object`CreateReservationRecord` entity contains the `Reservation` if there is an error/warning while performing the requested operation on it, otherwise it will contain the new `reservationId`.
-
-
Constructor Summary
Constructors Constructor Description CreateReservationRecord()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(java.lang.Object o)CreateReservationRecorderrors(ErrorList errors)ErrorListgetErrors()Get errorsReservationgetReservation()Get reservationWarningListgetWarnings()Get warningsinthashCode()CreateReservationRecordreservation(Reservation reservation)voidsetErrors(ErrorList errors)voidsetReservation(Reservation reservation)voidsetWarnings(WarningList warnings)java.lang.StringtoString()CreateReservationRecordwarnings(WarningList warnings)
-
-
-
Method Detail
-
reservation
public CreateReservationRecord reservation(Reservation reservation)
-
getReservation
public Reservation getReservation()
Get reservation- Returns:
- reservation
-
setReservation
public void setReservation(Reservation reservation)
-
warnings
public CreateReservationRecord warnings(WarningList warnings)
-
getWarnings
public WarningList getWarnings()
Get warnings- Returns:
- warnings
-
setWarnings
public void setWarnings(WarningList warnings)
-
errors
public CreateReservationRecord errors(ErrorList errors)
-
getErrors
public ErrorList getErrors()
Get errors- Returns:
- errors
-
setErrors
public void setErrors(ErrorList errors)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-