Class FixedSlotCapacityQuery
- java.lang.Object
-
- software.amazon.spapi.models.services.v1.FixedSlotCapacityQuery
-
public class FixedSlotCapacityQuery extends java.lang.ObjectRequest schema for the `getFixedSlotCapacity` operation. This schema is used to define the time range, capacity types and slot duration which are being queried.
-
-
Constructor Summary
Constructors Constructor Description FixedSlotCapacityQuery()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description FixedSlotCapacityQueryaddCapacityTypesItem(CapacityType capacityTypesItem)FixedSlotCapacityQuerycapacityTypes(java.util.List<CapacityType> capacityTypes)FixedSlotCapacityQueryendDateTime(org.threeten.bp.OffsetDateTime endDateTime)booleanequals(java.lang.Object o)java.util.List<CapacityType>getCapacityTypes()An array of capacity types which are being requested.org.threeten.bp.OffsetDateTimegetEndDateTime()End date time up to which the capacity slots are being requested in ISO 8601 format.java.math.BigDecimalgetSlotDuration()Size in which slots are being requested.org.threeten.bp.OffsetDateTimegetStartDateTime()Start date time from which the capacity slots are being requested in ISO 8601 format.inthashCode()voidsetCapacityTypes(java.util.List<CapacityType> capacityTypes)voidsetEndDateTime(org.threeten.bp.OffsetDateTime endDateTime)voidsetSlotDuration(java.math.BigDecimal slotDuration)voidsetStartDateTime(org.threeten.bp.OffsetDateTime startDateTime)FixedSlotCapacityQueryslotDuration(java.math.BigDecimal slotDuration)FixedSlotCapacityQuerystartDateTime(org.threeten.bp.OffsetDateTime startDateTime)java.lang.StringtoString()
-
-
-
Method Detail
-
capacityTypes
public FixedSlotCapacityQuery capacityTypes(java.util.List<CapacityType> capacityTypes)
-
addCapacityTypesItem
public FixedSlotCapacityQuery addCapacityTypesItem(CapacityType capacityTypesItem)
-
getCapacityTypes
public java.util.List<CapacityType> getCapacityTypes()
An array of capacity types which are being requested. Default value is `[SCHEDULED_CAPACITY]`.- Returns:
- capacityTypes
-
setCapacityTypes
public void setCapacityTypes(java.util.List<CapacityType> capacityTypes)
-
slotDuration
public FixedSlotCapacityQuery slotDuration(java.math.BigDecimal slotDuration)
-
getSlotDuration
public java.math.BigDecimal getSlotDuration()
Size in which slots are being requested. This value should be a multiple of 5 and fall in the range: 5 <= `slotDuration` <= 360.- Returns:
- slotDuration
-
setSlotDuration
public void setSlotDuration(java.math.BigDecimal slotDuration)
-
startDateTime
public FixedSlotCapacityQuery startDateTime(org.threeten.bp.OffsetDateTime startDateTime)
-
getStartDateTime
public org.threeten.bp.OffsetDateTime getStartDateTime()
Start date time from which the capacity slots are being requested in ISO 8601 format.- Returns:
- startDateTime
-
setStartDateTime
public void setStartDateTime(org.threeten.bp.OffsetDateTime startDateTime)
-
endDateTime
public FixedSlotCapacityQuery endDateTime(org.threeten.bp.OffsetDateTime endDateTime)
-
getEndDateTime
public org.threeten.bp.OffsetDateTime getEndDateTime()
End date time up to which the capacity slots are being requested in ISO 8601 format.- Returns:
- endDateTime
-
setEndDateTime
public void setEndDateTime(org.threeten.bp.OffsetDateTime endDateTime)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-