Class RangeSlotCapacityQuery
- java.lang.Object
-
- software.amazon.spapi.models.services.v1.RangeSlotCapacityQuery
-
public class RangeSlotCapacityQuery extends java.lang.ObjectRequest schema for the `getRangeSlotCapacity` operation. This schema is used to define the time range and capacity types that are being queried.
-
-
Constructor Summary
Constructors Constructor Description RangeSlotCapacityQuery()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description RangeSlotCapacityQueryaddCapacityTypesItem(CapacityType capacityTypesItem)RangeSlotCapacityQuerycapacityTypes(java.util.List<CapacityType> capacityTypes)RangeSlotCapacityQueryendDateTime(org.threeten.bp.OffsetDateTime endDateTime)booleanequals(java.lang.Object o)java.util.List<CapacityType>getCapacityTypes()An array of capacity types which are being requested.org.threeten.bp.OffsetDateTimegetEndDateTime()End date time up to which the capacity slots are being requested in ISO 8601 format.org.threeten.bp.OffsetDateTimegetStartDateTime()Start date time from which the capacity slots are being requested in ISO 8601 format.inthashCode()voidsetCapacityTypes(java.util.List<CapacityType> capacityTypes)voidsetEndDateTime(org.threeten.bp.OffsetDateTime endDateTime)voidsetStartDateTime(org.threeten.bp.OffsetDateTime startDateTime)RangeSlotCapacityQuerystartDateTime(org.threeten.bp.OffsetDateTime startDateTime)java.lang.StringtoString()
-
-
-
Method Detail
-
capacityTypes
public RangeSlotCapacityQuery capacityTypes(java.util.List<CapacityType> capacityTypes)
-
addCapacityTypesItem
public RangeSlotCapacityQuery addCapacityTypesItem(CapacityType capacityTypesItem)
-
getCapacityTypes
public java.util.List<CapacityType> getCapacityTypes()
An array of capacity types which are being requested. Default value is `[SCHEDULED_CAPACITY]`.- Returns:
- capacityTypes
-
setCapacityTypes
public void setCapacityTypes(java.util.List<CapacityType> capacityTypes)
-
startDateTime
public RangeSlotCapacityQuery startDateTime(org.threeten.bp.OffsetDateTime startDateTime)
-
getStartDateTime
public org.threeten.bp.OffsetDateTime getStartDateTime()
Start date time from which the capacity slots are being requested in ISO 8601 format.- Returns:
- startDateTime
-
setStartDateTime
public void setStartDateTime(org.threeten.bp.OffsetDateTime startDateTime)
-
endDateTime
public RangeSlotCapacityQuery endDateTime(org.threeten.bp.OffsetDateTime endDateTime)
-
getEndDateTime
public org.threeten.bp.OffsetDateTime getEndDateTime()
End date time up to which the capacity slots are being requested in ISO 8601 format.- Returns:
- endDateTime
-
setEndDateTime
public void setEndDateTime(org.threeten.bp.OffsetDateTime endDateTime)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-