Enum EventCode
- java.lang.Object
-
- java.lang.Enum<EventCode>
-
- software.amazon.spapi.models.shipping.v2.EventCode
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classEventCode.Adapter
-
Enum Constant Summary
Enum Constants Enum Constant Description ARRIVEDATCARRIERFACILITYAVAILABLEFORPICKUPDELIVEREDDELIVERYATTEMPTEDDEPARTEDLOSTOUTFORDELIVERYPICKUPCANCELLEDPICKUPDONEREADYFORRECEIVERECIPIENTREQUESTEDALTERNATEDELIVERYTIMINGREJECTEDRETURNINITIATEDUNDELIVERABLE
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static EventCodefromValue(java.lang.String input)java.lang.StringgetValue()java.lang.StringtoString()static EventCodevalueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static EventCode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
READYFORRECEIVE
@SerializedName("ReadyForReceive") public static final EventCode READYFORRECEIVE
-
PICKUPDONE
@SerializedName("PickupDone") public static final EventCode PICKUPDONE
-
DELIVERED
@SerializedName("Delivered") public static final EventCode DELIVERED
-
DEPARTED
@SerializedName("Departed") public static final EventCode DEPARTED
-
DELIVERYATTEMPTED
@SerializedName("DeliveryAttempted") public static final EventCode DELIVERYATTEMPTED
-
LOST
@SerializedName("Lost") public static final EventCode LOST
-
OUTFORDELIVERY
@SerializedName("OutForDelivery") public static final EventCode OUTFORDELIVERY
-
ARRIVEDATCARRIERFACILITY
@SerializedName("ArrivedAtCarrierFacility") public static final EventCode ARRIVEDATCARRIERFACILITY
-
REJECTED
@SerializedName("Rejected") public static final EventCode REJECTED
-
UNDELIVERABLE
@SerializedName("Undeliverable") public static final EventCode UNDELIVERABLE
-
PICKUPCANCELLED
@SerializedName("PickupCancelled") public static final EventCode PICKUPCANCELLED
-
RETURNINITIATED
@SerializedName("ReturnInitiated") public static final EventCode RETURNINITIATED
-
AVAILABLEFORPICKUP
@SerializedName("AvailableForPickup") public static final EventCode AVAILABLEFORPICKUP
-
RECIPIENTREQUESTEDALTERNATEDELIVERYTIMING
@SerializedName("RecipientRequestedAlternateDeliveryTiming") public static final EventCode RECIPIENTREQUESTEDALTERNATEDELIVERYTIMING
-
-
Method Detail
-
values
public static EventCode[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (EventCode c : EventCode.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static EventCode valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
java.lang.IllegalArgumentException- if this enum type has no constant with the specified namejava.lang.NullPointerException- if the argument is null
-
getValue
public java.lang.String getValue()
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Enum<EventCode>
-
fromValue
public static EventCode fromValue(java.lang.String input)
-
-