Class RequestedLabelCustomization
- java.lang.Object
-
- software.amazon.spapi.models.shipping.v2.RequestedLabelCustomization
-
public class RequestedLabelCustomization extends java.lang.ObjectObject contains customised data requested by a shipper to be printed on a shipping label.
-
-
Constructor Summary
Constructors Constructor Description RequestedLabelCustomization()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(java.lang.Object o)RequestAttributesgetRequestAttributes()Get requestAttributesinthashCode()RequestedLabelCustomizationrequestAttributes(RequestAttributes requestAttributes)voidsetRequestAttributes(RequestAttributes requestAttributes)java.lang.StringtoString()
-
-
-
Method Detail
-
requestAttributes
public RequestedLabelCustomization requestAttributes(RequestAttributes requestAttributes)
-
getRequestAttributes
public RequestAttributes getRequestAttributes()
Get requestAttributes- Returns:
- requestAttributes
-
setRequestAttributes
public void setRequestAttributes(RequestAttributes requestAttributes)
-
equals
public boolean equals(java.lang.Object o)
- Overrides:
equalsin classjava.lang.Object
-
hashCode
public int hashCode()
- Overrides:
hashCodein classjava.lang.Object
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-